==> senior_platform_authentication_ui-3.1.0.tar.gz: lib/src/core/authentication/domain/usecases/check_stored_token_usecase.dart <==
import 'package:senior_platform_authentication/senior_platform_authentication.dart';
import 'package:senior_platform_authentication_ui/src/core/authentication/domain/usecases/check_status_connection_usecase.dart';

import '../../data/repositories/secure_storage_repository.dart';
import '../entities/user_name.dart';

class CheckStoredTokenUsecase implements BaseUsecase<bool, UserName> {
  late final SecureStorageRepository _secureStorageRepository;
  late final GetUserUsecase _getUserUsecase;
  late final CheckStatusConnectionUsecase _checkStatusConnectionUsecase;

  CheckStoredTokenUsecase({
    SecureStorageRepository? secureStorageRepository,
    required GetUserUsecase getUserUsecase,
    required CheckStatusConnectionUsecase checkStatusConnectionUsecase,
  }) {
    _secureStorageRepository =
        secureStorageRepository ?? SecureStorageRepositoryImpl();
    _getUserUsecase = getUserUsecase;
    _checkStatusConnectionUsecase = checkStatusConnectionUsecase;
  }

  @override
  Future<bool> call(UserName username) async {
    try {
      final currentUsername = username.currentUsername?.isEmpty ?? true
          ? await _secureStorageRepository.readLastUser() ?? ''
          : username.currentUsername!;

      final token =
          await _secureStorageRepository.readToken(username: currentUsername);

      final tokenExpirationDate = await _secureStorageRepository
          .readTokenExpirationDate(username: currentUsername);

      if (token == null) {
        return false;
      }

      if (token.accessToken.isEmpty) {
        return false;
      }

      if (token.refreshToken.isEmpty) {
        return false;
      }

      if (tokenExpirationDate == null) {
        return false;
      }

      if (tokenExpirationDate.isBefore(DateTime.now())) {
        return false;
      }

      final isOnline = await _checkStatusConnectionUsecase.call(NoParams());
      if (isOnline) {
        await _getUserUsecase.call(token.accessToken);
      }

      return true;
    } catch (_) {
      return false;
    }
  }
}

==> senior_platform_authentication_ui-3.2.0.tar.gz: lib/src/core/authentication/domain/usecases/check_stored_token_usecase.dart <==
import 'package:senior_platform_authentication/senior_platform_authentication.dart';
import 'package:senior_platform_authentication_ui/src/core/authentication/domain/usecases/check_status_connection_usecase.dart';

import '../../data/repositories/secure_storage_repository.dart';
import '../entities/user_name.dart';

class CheckStoredTokenUsecase implements BaseUsecase<bool, UserName> {
  late final SecureStorageRepository _secureStorageRepository;
  late final GetUserUsecase _getUserUsecase;
  late final CheckStatusConnectionUsecase _checkStatusConnectionUsecase;

  CheckStoredTokenUsecase({
    SecureStorageRepository? secureStorageRepository,
    required GetUserUsecase getUserUsecase,
    required CheckStatusConnectionUsecase checkStatusConnectionUsecase,
  }) {
    _secureStorageRepository =
        secureStorageRepository ?? SecureStorageRepositoryImpl();
    _getUserUsecase = getUserUsecase;
    _checkStatusConnectionUsecase = checkStatusConnectionUsecase;
  }

  @override
  Future<bool> call(UserName username) async {
    try {
      final currentUsername = username.currentUsername?.isEmpty ?? true
          ? await _secureStorageRepository.readLastUser() ?? ''
          : username.currentUsername!;

      final token =
          await _secureStorageRepository.readToken(username: currentUsername);

      final tokenExpirationDate = await _secureStorageRepository
          .readTokenExpirationDate(username: currentUsername);

      if (token == null) {
        return false;
      }

      if (token.accessToken.isEmpty) {
        return false;
      }

      if (token.refreshToken.isEmpty) {
        return false;
      }

      if (tokenExpirationDate == null) {
        return false;
      }

      if (tokenExpirationDate.isBefore(DateTime.now())) {
        return false;
      }

      final isOnline = await _checkStatusConnectionUsecase.call(NoParams());
      if (isOnline) {
        await _getUserUsecase.call(
          GetUserInput(
            accessToken: token.accessToken,
            includePhoto: SeniorAuthentication.includePhoto,
          ),
        );
      }

      return true;
    } catch (_) {
      return false;
    }
  }
}
